@@ -4,10 +4,7 @@
 # 	fSeries Functions Addons
 #
 # Description:
-#	This is a collection of frunctions which support the following
-#	tasks:
-#    1 Aparch Time Series Simulation
-#    2 Chaotic Time Series Maps
+#	This is a collection of frunctions which support the following tasks:
 #    3 Absolute Moment Statistics
 #    4 Garch Ox Interface
 #    5 Missing Data Manipulations
@@ -24,312 +21,6 @@
 #
 
 
-################################################################################
-# 1 APARCH TIME SERIES SIMULATION
-
-
-################################################################################
-# FUNCTION:       DESCRIPTION:
-#  .aparchSim      Simulate an APARCH time series process 
-################################################################################
-
-
-.aparchSim = 
-function(model = list(omega = 1e-6, alpha = 0.1, gamma = 0, alpha.lags = 1,
-beta = 0.8, beta.lags = 1, delta = 1), n = 1000, innov = NULL, n.start = 100, 
-start.innov = NULL, rand.gen = rnorm, ...)
-{   # A function implemented by D. Wuertz   
-
-    # Description:
-    #   Simulate an APARCH time series process
-    
-    # Notes:
-    #   This function is written completely in R without the needs of 
-    #   a compiled external function.
-    
-    # FUNCTION:
-    
-    # Innovations:      
-    if (is.null(innov)) innov = rand.gen(n, ...)
-    if (is.null(start.innov)) start.innov = rand.gen(n.start, ...)  
-    x = z = c(start.innov, innov)
-    h = 0 * x 
-     
-    # Order maxpq:
-    deltainv = 1/model$delta    
-    maxpq = max( 
-        model$alpha.lags[length(model$alpha.lags)], 
-        model$beta.lags[length(model$beta.lags)] )
-    
-    # Simulate:
-    for (n in (maxpq+1):length(z)) {     
-        h[n] = model$omega +    
-            sum(model$alpha*(abs(abs(x[n-model$alpha.lags]) - 
-                model$gamma*x[n-model$alpha.lags])^model$delta)) +
-            sum(model$beta*h[n-model$beta.lags]) 
-        x[n] = h[n]**deltainv * z[n] }
-        
-    # Return Value:
-    as.ts(x[(length(start.innov)+1):length(z)])
-}
-
-
-################################################################################
-# 2 CHAOTIC TIME SERIES MAPS
-
-
-################################################################################
-# FUNCTION:       DESCRIPTION:
-#  henonSim        Simulate data from Henon Map 
-#  ikedaSim        Simulate data from Ikeda Map
-#  logisticSim     Simulate data from Logistic Map
-#  lorentzSim      Simulate data from Lorentz Map
-#  roesslerSim     Simulate data from Roessler Map
-################################################################################
-
-
-henonSim = 
-function(n = 1000, n.skip = 100, a = 1.4, b = 0.3, x.start = runif(1), 
-y.start = runif(1), doplot = FALSE)
-{   # A function implemented by Diethelm Wuertz
-    
-    # Description:
-    #   Simulate Data from Henon Map
-    
-    # Details:
-    #   Creates iterates of the Henon map:
-    #   *   x(n+1)  =  1 - a*x(n)^2 + b*y(n)
-    #   *   y(n+1)  =  x(n)
-
-    # Argument List:
-    #   Name:   Description:
-    #   n       number of points x, y
-    #   n.skip  number of transients discarded
-    #   a       parameter a
-    #   b       parameter b
-    #   x       initial x
-    #   y       initial y
-    
-    # Copyright and License:
-    #   Diethelm Wuertz, GPL
-    
-    # FUNCTION:
-    
-    # Simulate Map: 
-    x = rep(0, times = (n+n.skip))
-    y = rep(0, times = (n+n.skip))
-    x[1] = x.start
-    y[1] = y.start
-    for ( i in 2:(n+n.skip) ) {
-        x[i]  =  1 - a*x[i-1]^2 + b*y[i-1]
-        y[i]  =  x[i-1] }
-    x = x[(n.skip+1):(n.skip+n)] 
-    y = y[(n.skip+1):(n.skip+n)] 
-
-    # Plot Map:
-    if (doplot) {
-        plot(x = x, y = y, type = "n", xlab = "x[n]", ylab = "y[n]", 
-        main = "Henon Map")
-        points(x = x, y = y, col = "red", cex = 0.25) }
-    
-    # Return Value:
-    data.frame(x, y)    
-}
-
-
-# ------------------------------------------------------------------------------
-
-
-ikedaSim = 
-function(n = 1000, n.skip = 100, a = 0.4, b = 6.0, c = 0.9, x = runif(1), 
-y = runif(1), doplot = FALSE)
-{   # A function written by Diethelm Wuertz
-
-    # Description:
-    #   Simulate Ikeda Map Data
-    
-    # Details:
-    #   Prints iterates of the Ikeda map (Re(z) and Im(z)): 
-    #                                        i*b
-    #   z(n+1)  =  1 + c*z(n)* exp( i*a - ------------ )
-    #                                     1 + |z(n)|^2
-
-    # Argument List:
-    #   Name:   Description:
-    #   n       number of points z
-    #   n.skip  number of transients discarded
-    #   a       parameter a
-    #   b       parameter b; 6.0 
-    #   c       parameter c; 0.9 
-    #   x       initial Re(z); runif(1)
-    #   y       initial Im(z); runif(1)
-    
-    # Copyright and License:
-    #   Diethelm Wuertz, GPL
-    
-    # FUNCTION:
-    
-    # Simulate Map: 
-    a = complex(real = 0, imag = a)
-    b = complex(real = 0, imag = b)
-    z = rep(complex(real = x, imag = y), times = (n+n.skip))
-    for ( i in 2:(n+n.skip) ) {
-        z[i] = 1 + c*z[i-1] * exp(a-b/(1+abs(z[i-1])^2)) }
-    z = z[(n.skip+1):(n.skip+n)] 
-    
-    # Plot Map:
-    if (doplot) {
-        x = Re(z); y = Im(z)
-        plot(x, y, type = "n", xlab = "x[n]", ylab = "y[n]", 
-            main = "Ikeda Map")
-        points(x, y, col = "red", cex = 0.25)
-        x = Re(z)[1:(length(z)-1)]; y = Re(z)[2:length(z)]
-        plot(x, y, type = "n", xlab = "x[n]", ylab = "x[n+1]", 
-            main = "Ikeda Map")
-        points(x, y, col = "red", cex = 0.25) }
-    
-    # Return Value:
-    data.frame(Re(z), Im(z), col.names = c("x", "y"))   
-}
- 
-
-# ------------------------------------------------------------------------------
-
-
-logisticSim = 
-function(n = 1000, n.skip = 100, r = 4, x.start = runif(1), doplot = FALSE)
-{   # A function written by Diethelm Wuertz
-    
-    # Description:
-    #   Simulate Data from Logistic Map
-    
-    # Details:
-    #   Creates iterates of the Logistic Map:
-    #   *   x(n+1)  =  r * x[n] * ( 1 - x[n] )
-
-    # Argument List:
-    #   Name:   Description:
-    #   n       number of points x, y
-    #   n.skip  number of transients discarded
-    #   r       parameter r
-    #   x.start initial x
-    
-    # Copyright and License:
-    #   Diethelm Wuertz, GPL
-    
-    # FUNCTION:
-    
-    # Simulate Map: 
-    x = rep(0, times = (n+n.skip))
-    x[1] = x.start
-    for ( i in 2:(n+n.skip) ) {
-        x[i]  =  r * x[i-1] * ( 1 - x[i-1] ) }
-    x = x[(n.skip+1):(n.skip+n)] 
-
-    # Plot Map:
-    if (doplot) {
-        plot(x = x[1:(n-1)], y = x[2:n], type = "n", xlab = "x[n-1]", 
-            ylab = "x[n]", main = "Logistic Map")
-        points(x = x[1:(n-1)], y = x[2:n], col = "red", cex = 0.25) }
-    
-    # Return Value:
-    data.frame(x)   
-}
-    
-                       
-# ------------------------------------------------------------------------------
-
-
-lorentzSim = 
-function(times = seq(0, 40, by = 0.01), parms = c(sigma = 16, r = 45.92, b = 4),
-start = c(-14, -13, 47), doplot = TRUE, ...)
-{   # A function written by Diethelm Wuertz
-
-    # Description:
-    #   Simulates a Lorentz Map
-    
-    # Notes:
-    #   Requires contributed R package "odesolve"
-    
-    # Copyright and License:
-    #   Diethelm Wuertz, GPL
-   
-    # FUNCTION:
-    
-    # Requirements:
-    require(odesolve)
-    
-    # Attractor:
-    lorentz = function(t, x, parms) {
-        X = x[1]; Y = x[2]; Z = x[3] 
-        with(as.list(parms), {
-            dX = sigma * ( Y - X )
-            dY = -X*Z + r*X - Y
-            dZ = X*Y - b*Z
-            list(c(dX, dY, dZ))}) }
-
-    # Classical RK4 with fixed time step:
-    s = rk4(start, times, lorentz, parms)
-
-    # Display:
-    if (doplot) {
-        xylab = c("x", "y", "z", "x")
-        for (i in 2:4) plot(s[, 1], s[, i], type = "l", 
-            xlab = "t", ylab = xylab[i-1], main =  "Roessler", ...)
-        k = c(3, 4, 2)
-        for (i in 2:4) plot(s[, i], s[, k[i-1]], type = "l", 
-            xlab = xylab[i-1], ylab = xylab[i], main =  "Roessler", ...) }
-        
-    # Return Value:
-    invisible(s)
-}
-
-
-# ------------------------------------------------------------------------------
-
-
-roesslerSim = 
-function(times = seq(0, 100, by = 0.01), parms = c(a = 0.2, b = 0.2, c = 8.0),
-start = c(-1.894, -9.920, 0.0250), doplot = TRUE, ...)
-{   # A function written by Diethelm Wuertz
-    
-    # Description:
-    #   Simulates a Lorentz Map
-    
-    # Notes:
-    #   Requires contributed R package "odesolve"
-    
-    # Copyright and License:
-    #   Diethelm Wuertz, GPL
-   
-    # FUNCTION:
-    
-    # Attractor:
-    roessler = function(t, x, parms) {
-        X = x[1]; Y = x[2]; Z = x[3] 
-        with(as.list(parms), {
-            dX = -(Y+Z)
-            dY = X + a*Y
-            dZ = b + X*Z -c*Z
-            list(c(dX, dY, dZ))}) }
-
-    # Classical RK4 with fixed time step:
-    s = rk4(start, times, roessler, parms)
-
-    # Display:
-    if (doplot) {
-        xylab = c("x", "y", "z", "x")
-        for (i in 2:4) plot(s[, 1], s[, i], type = "l", 
-            xlab = "t", ylab = xylab[i-1], main =  "Roessler", ...)
-        k = c(3, 4, 2)
-        for (i in 2:4) plot(s[, i], s[, k[i-1]], type = "l", 
-            xlab = xylab[i-1], ylab = xylab[i], main =  "Roessler", ...) }
-        
-    # Return Value:
-    invisible(s)
-}
-
-
 ################################################################################
 # 3 ABSOLUTE MOMENT STATISTICS
 
